Learn R Programming

rijkspalette (version 1.0.2)

explore: Explore a rijkspalette

Description

This function plots the available colours in ab-space along with the cluster centroids used to generate the palette. By manipulating the number of clusters, each distinct colour category can receive its own centroid. This function was designed to work in RStudio.

Usage

explore(x, ...)

Arguments

x

A rijkspalette object

...

other arguments passed to plot function

See Also

tune

rijksPalette