Learn R Programming

rijkspalette (version 1.0.2)

rijksPalette: Rijkspalette function

Description

This function queries the Rijksmuseum collection for paintings and returns a colour palette based on colours from that painting.

Usage

rijksPalette(query)

Arguments

query

Keyword to search for in the collection of the Rijksmuseum

Value

an object of type rijkspalette

See Also

tune

explore

Examples

Run this code
# NOT RUN {
pal <- rijksPalette("Vermeer Letter")
# }
# NOT RUN {
plot(pal)
barplot(1/sqrt(1:15), col = pal$palette(15))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab