Learn R Programming

rijkspalette (version 1.0.2)

tune: Tune a rijkspalette

Description

This function tunes the extracted palette from an image in a rijksPalette object. Often, the defaults need to be tuned a little to get the nicest results.

Usage

tune(x, lightness, k)

Arguments

x

rijkspalette object

lightness

overall lightness between 0 (darkest) and 1 (brightest)

k

number of colours to extract

See Also

explore

rijksPalette