powered by
This function queries the Rijksmuseum collection for paintings and returns a colour palette based on colours from that painting.
rijksPalette(query)
Keyword to search for in the collection of the Rijksmuseum
an object of type rijkspalette
rijkspalette
tune
explore
# NOT RUN { pal <- rijksPalette("Vermeer Letter") # } # NOT RUN { plot(pal) barplot(1/sqrt(1:15), col = pal$palette(15)) # } # NOT RUN { # }
Run the code above in your browser using DataLab